View source: R/special_sphere.R
| sphere.runif | R Documentation |
It generates n random samples from \mathcal{S}^{p-1}. For convenient
usage of users, we provide a number of options in terms of the return type.
sphere.runif(n, p, type = c("list", "matrix", "riemdata"))
n |
number of samples to be generated. |
p |
original dimension (of the ambient space). |
type |
return type;
|
an object from one of the above by type option.
chikuse_statistics_2003Riemann
wrap.sphere
#-------------------------------------------------------------------
# Draw Samples on Sphere
#
# Multiple return types on S^4 in R^5
#-------------------------------------------------------------------
dat.list = sphere.runif(n=10, p=5, type="list")
dat.matx = sphere.runif(n=10, p=5, type="matrix")
dat.riem = sphere.runif(n=10, p=5, type="riemdata")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.